==> nextcloud-13.0.1.tgz: nextcloud/settings/l10n/sl.js <==
OC.L10N.register(
    "settings",
    {
    "{actor} changed your password" : "{actor} vaše geslo je spremenjeno",
    "You changed your password" : "Spremenili ste vaše geslo",
    "Wrong password" : "Napačno geslo",
    "Saved" : "Shranjeno",
    "No user supplied" : "Ni navedenega uporabnika",
    "Unable to change password" : "Ni mogoče spremeniti gesla",
    "Authentication error" : "Napaka med overjanjem",
    "Wrong admin recovery password. Please check the password and try again." : "Napačno navedeno skrbniško obnovitveno geslo. Preverite geslo in poskusite znova.",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "nameščanje in posodabljanje programov prek programske zbirke ali zveznega oblaka",
    "Federated Cloud Sharing" : "Souporaba zveznega oblaka",
    "Group already exists." : "Skupina že obstaja.",
    "Unable to add group." : "Ni mogoče dodati skupine",
    "Unable to delete group." : "Ni mogoče izbrisati skupine.",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Med pošiljanjem sporočila se je prišlo do napake. Preverite nastavitve (napaka: %s).",
    "You need to set your user email before being able to send test emails." : "Pred preizkusnim pošiljanjem sporočil je treba nastaviti elektronski naslov uporabnika.",
    "Invalid mail address" : "Neveljaven elektronski naslov",
    "A user with that name already exists." : "Uporabnik s tem imenom že obstaja.",
    "Unable to create user." : "Ni mogoče ustvariti uporabnika.",
    "Unable to delete user." : "Ni mogoče izbrisati uporabnika",
    "Unable to change full name" : "Ni mogoče spremeniti polnega imena",
    "Your full name has been changed." : "Vaše polno ime je spremenjeno.",
    "Forbidden" : "Dostop je prepovedan",
    "Invalid user" : "Neveljavni podatki uporabnika",
    "Unable to change mail address" : "Ni mogoče spremeniti naslova elektronske pošte.",
    "Email saved" : "Elektronski naslov je shranjen",
    "Your %s account was created" : "Račun %s je uspešno ustvarjen.",
    "Set your password" : "Nastavi vaše geslo",
    "Couldn't remove app." : "Ni mogoče odstraniti programa.",
    "Couldn't update app." : "Programa ni mogoče posodobiti.",
    "Add trusted domain" : "Dodaj varno domeno",
    "Migration in progress. Please wait until the migration is finished" : "V teku je selitev. Počakajte, da se zaključi.",
    "Migration started …" : "Selitev je začeta ...",
    "Email sent" : "Elektronska pošta je poslana",
    "Official" : "Uradno",
    "All" : "Vsi",
    "Update to %s" : "Posodobi na %s",
    "No apps found for your version" : "Za to različico ni na voljo noben vstavek",
    "The app will be downloaded from the app store" : "Program bo prejet iz zbirke programov",
    "Error while disabling app" : "Napaka onemogočanja programa",
    "Disable" : "Onemogoči",
    "Enable" : "Omogoči",
    "Error while enabling app" : "Napaka omogočanja programa",
    "Error while disabling broken app" : "Napaka onemogočanja okvarjenega programa",
    "Updated" : "Posodobljeno",
    "Approved" : "Odobreno",
    "Experimental" : "Preizkusno",
    "No apps found for {query}" : "Ni programov, skladnih z nizom \"{query}\".",
    "Disconnect" : "Prekinjeni povezavo",
    "Error while loading browser sessions and device tokens" : " Napaka med nalaganjem brskalnika in ključev naprave",
    "Error while creating device token" : " Napaka med izdelavo ključa naprave",
    "Error while deleting the token" : " Napaka med brisanjem ključa",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Prišlo je do napake. Uvoziti je treba ustrezno ASCII kodirano potrdilo PEM.",
    "Valid until {date}" : "Veljavno do {date}",
    "Delete" : "Izbriši",
    "Select a profile picture" : "Izbor slike profila",
    "Very weak password" : "Zelo šibko geslo",
    "Weak password" : "Šibko geslo",
    "So-so password" : "Slabo geslo",
    "Good password" : "Dobro geslo",
    "Strong password" : "Odlično geslo",
    "Groups" : "Skupine",
    "Unable to delete {objName}" : "Ni mogoče izbrisati {objName}",
    "Error creating group: {message}" : "Napaka ustvarjanja skupine: {message}",
    "A valid group name must be provided" : "Navedeno mora biti veljavno ime skupine",
    "deleted {groupName}" : "izbrisano {groupName}",
    "undo" : "razveljavi",
    "never" : "nikoli",
    "deleted {userName}" : "izbrisano {userName}",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "Sprememba gesla bo povzročila izgubo podatkov, ker obnova podatkov za tega uporabnika ni na voljo.",
    "A valid username must be provided" : "Navedeno mora biti veljavno uporabniško ime",
    "Error creating user: {message}" : "Napaka ustvarjanja uporabnika: {message}",
    "Developer documentation" : "Dokumentacija za razvijalce",
    "%s-licensed" : "dovoljenje-%s",
    "Documentation:" : "Dokumentacija:",
    "User documentation" : "Uporabniška dokumentacija",
    "Admin documentation" : "Skrbniška dokumentacija",
    "Visit website" : "Obiščite spletno stran",
    "Report a bug" : "Pošlji poročilo o hrošču",
    "Show description …" : "Pokaži opis ...",
    "Hide description …" : "Skrij opis ...",
    "This app has an update available." : "Za program so na voljo posodobitve.",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Ta aplikacija nima določene minimalne NextCloud verzije. V prihodnosti bo to napaka.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Ta aplikacija nima določene maksimalne NextCloud verzije. V prihodnosti bo to napaka.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Programa ni mogoče namestiti zaradi nerešenih odvisnosti:",
    "Enable only for specific groups" : "Omogoči le za posamezne skupine",
    "SSL Root Certificates" : "Korenska potrdila SSL",
    "Common Name" : "Splošno ime",
    "Valid until" : "Veljavno do",
    "Issued By" : "Izdajatelj",
    "Valid until %s" : "Veljavno do %s",
    "Import root certificate" : "Uvozi korensko potrdilo",
    "Administrator documentation" : "Skrbniška dokumentacija",
    "Online documentation" : "Spletna dokumentacija",
    "Forum" : "Forum",
    "Commercial support" : "Podpora strankam",
    "None" : "Brez",
    "Login" : "Prijava",
    "Plain" : "Besedilno",
    "NT LAN Manager" : "Upravljalnik NT LAN",
    "Email server" : "Poštni strežnik",
    "Open documentation" : "Odprta dokumentacija",
    "Send mode" : "Način pošiljanja",
    "Encryption" : "Šifriranje",
    "From address" : "Naslov pošiljatelja",
    "mail" : "pošta",
    "Authentication method" : "Način overitve",
    "Authentication required" : "Zahtevana je overitev",
    "Server address" : "Naslov strežnika",
    "Port" : "Vrata",
    "Credentials" : "Poverila",
    "SMTP Username" : "Uporabniško ime SMTP",
    "SMTP Password" : "Geslo SMTP",
    "Store credentials" : "Shrani poverila",
    "Test email settings" : "Preizkus nastavitev elektronske pošte",
    "Send email" : "Pošlji elektronsko sporočilo",
    "Server-side encryption" : "Šifriranje na strežniku",
    "Enable server-side encryption" : "Omogoči šifriranje na strežniku",
    "Please read carefully before activating server-side encryption: " : "Pozorno preberite opombe, preden omogočite strežniško šifriranje:",
    "Be aware that encryption always increases the file size." : " Upoštevajte, da šifriranje vedno poveča velikost datoteke.",
    "This is the final warning: Do you really want to enable encryption?" : " To je zadnje opozorilo. Ali resnično želite vključiti šifriranje?",
    "Enable encryption" : "Omogoči šifriranje",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Modul za šifriranje ni naložen. Prosim, omogočite en šifrirni modul v spisku aplikacij.",
    "Select default encryption module:" : "Izbor privzetega modula za šifriranje:",
    "Start migration" : "Začni selitev",
    "Security & setup warnings" : "Varnost in namestitvena opozorila",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Napako je najverjetneje povzročil predpomnilnik ali pospeševalnik, kot sta Zend OPcache ali eAccelerator.",
    "System locale can not be set to a one which supports UTF-8." : "Sistemskih jezikovnih nastavitev ni mogoče nastaviti na možnost, ki podpira nabor UTF-8.",
    "All checks passed." : "Vsa preverjanja so uspešno zaključena.",
    "Execute one task with each page loaded" : "Izvedi eno nalogo z vsako naloženo stranjo.",
    "Version" : "Različica",
    "Sharing" : "Souporaba",
    "Allow apps to use the Share API" : "Dovoli programom uporabo vmesnika API souporabe",
    "Allow users to share via link" : "Uporabnikom dovoli omogočanje souporabe s povezavami",
    "Allow public uploads" : "Dovoli javno pošiljanje datotek v oblak",
    "Enforce password protection" : "Vsili zaščito z geslom",
    "Set default expiration date" : "Nastavitev privzetega datuma poteka",
    "Expire after " : "Preteče po",
    "days" : "dneh",
    "Enforce expiration date" : "Vsili datum preteka",
    "Allow resharing" : "Dovoli nadaljnjo souporabo",
    "Allow sharing with groups" : "Dovoli souporabo s skupinami",
    "Restrict users to only share with users in their groups" : "Uporabnikom dovoli omogočanje souporabe le znotraj njihove skupine",
    "Exclude groups from sharing" : "Izloči skupine iz souporabe",
    "These groups will still be able to receive shares, but not to initiate them." : "Te skupine lahko sprejemajo mape v souporabo, ne morejo pa souporabe dovoliti",
    "Tips & tricks" : "Nasveti in triki",
    "How to do backups" : "Kako ustvariti varnostne kopije",
    "Performance tuning" : "Prilagajanje delovanja",
    "Improving the config.php" : "Izboljšave v config.php",
    "Theming" : "Teme",
    "Hardening and security guidance" : "Varnost in varnostni napotki",
    "You are using <strong>%s</strong> of <strong>%s</strong>" : "Uporabljate <strong>%s</strong> od <strong>%s</strong>",
    "Profile picture" : "Slika profila",
    "Upload new" : "Pošlji novo",
    "Select from Files" : "Izbor iz datotek",
    "Remove image" : "Odstrani sliko",
    "png or jpg, max. 20 MB" : "png ali jpg, največ. 20 MB",
    "Picture provided by original account" : "Slika iz originalnega računa",
    "Cancel" : "Prekliči",
    "Choose as profile picture" : "Izberi kot sliko profila",
    "Full name" : "Polno ime",
    "No display name set" : "Prikazno ime ni nastavljeno",
    "Email" : "Elektronski naslov",
    "Your email address" : "Osebni elektronski naslov",
    "No email address set" : "Poštni naslov ni nastavljen",
    "You are member of the following groups:" : "Ste član naslednjih skupin:",
    "Language" : "Jezik",
    "Help translate" : "Sodelujte pri prevajanju",
    "Password" : "Geslo",
    "Current password" : "Trenutno geslo",
    "New password" : "Novo geslo",
    "Change password" : "Spremeni geslo",
    "App name" : "Ime aplikacije",
    "Create new app password" : "Ustvari novo geslo aplikacije",
    "Username" : "Uporabniško ime",
    "Done" : "Končano",
    "Show storage location" : "Pokaži mesto shrambe",
    "Show user backend" : "Pokaži ozadnji program",
    "Everyone" : "Vsi",
    "Admins" : "Skrbniki",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Vnesite količinsko omejitev prostora (na primer: \"512 MB\" ali \"12 GB\")",
    "Unlimited" : "Neomejeno",
    "Other" : "Drugo",
    "Quota" : "Količinska omejitev",
    "E-Mail" : "Elektronska pošta",
    "Admin Recovery Password" : "Obnovitev skrbniškega gesla",
    "Enter the recovery password in order to recover the users files during password change" : "Vnesite geslo, ki omogoča obnovitev uporabniških datotek med spreminjanjem gesla",
    "change full name" : "Spremeni polno ime",
    "set new password" : "nastavi novo geslo",
    "change email address" : "spremeni naslov elektronske pošte",
    "Default" : "Privzeto",
    "A problem occurred, please check your log files (Error: %s)" : "Prišlo je do napake. Preverite dnevniške zapise (napaka: %s).",
    "Migration Completed" : "Selitev je končana",
    "A valid password must be provided" : "Navedeno mora biti veljavno geslo",
    "A valid email must be provided" : "Naveden mora biti veljaven naslov elektronske pošte.",
    "Show email address" : "Pokaži naslov elektronske pošte",
    "Send email to new user" : "Pošlji sporočilo novemu uporabniku",
    "Create" : "Ustvari"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> nextcloud-14.0.1.tgz: nextcloud/settings/l10n/sl.js <==
OC.L10N.register(
    "settings",
    {
    "{actor} changed your password" : "{actor} vaše geslo je spremenjeno",
    "You changed your password" : "Spremenili ste vaše geslo",
    "Couldn't remove app." : "Ni mogoče odstraniti programa.",
    "Couldn't update app." : "Programa ni mogoče posodobiti.",
    "Wrong password" : "Napačno geslo",
    "Saved" : "Shranjeno",
    "No user supplied" : "Ni navedenega uporabnika",
    "Unable to change password" : "Ni mogoče spremeniti gesla",
    "Authentication error" : "Napaka med overjanjem",
    "Wrong admin recovery password. Please check the password and try again." : "Napačno navedeno skrbniško obnovitveno geslo. Preverite geslo in poskusite znova.",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "nameščanje in posodabljanje programov prek programske zbirke ali zveznega oblaka",
    "Federated Cloud Sharing" : "Souporaba zveznega oblaka",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Med pošiljanjem sporočila se je prišlo do napake. Preverite nastavitve (napaka: %s).",
    "You need to set your user email before being able to send test emails." : "Pred preizkusnim pošiljanjem sporočil je treba nastaviti elektronski naslov uporabnika.",
    "Invalid mail address" : "Neveljaven elektronski naslov",
    "Unable to change full name" : "Ni mogoče spremeniti polnega imena",
    "Your %s account was created" : "Račun %s je uspešno ustvarjen.",
    "Set your password" : "Nastavi vaše geslo",
    "Migration in progress. Please wait until the migration is finished" : "V teku je selitev. Počakajte, da se zaključi.",
    "Migration started …" : "Selitev je začeta ...",
    "Email sent" : "Elektronska pošta je poslana",
    "Disconnect" : "Prekinjeni povezavo",
    "Error while loading browser sessions and device tokens" : " Napaka med nalaganjem brskalnika in ključev naprave",
    "Error while creating device token" : " Napaka med izdelavo ključa naprave",
    "Error while deleting the token" : " Napaka med brisanjem ključa",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Prišlo je do napake. Uvoziti je treba ustrezno ASCII kodirano potrdilo PEM.",
    "Valid until {date}" : "Veljavno do {date}",
    "Delete" : "Izbriši",
    "Very weak password" : "Zelo šibko geslo",
    "Weak password" : "Slabo geslo",
    "So-so password" : "Šibko geslo",
    "Good password" : "Dobro geslo",
    "Strong password" : "Odlično geslo",
    "Select a profile picture" : "Izbor slike profila",
    "Groups" : "Skupine",
    "Official" : "Uradno",
    "Visit website" : "Obiščite spletno stran",
    "User documentation" : "Uporabniška dokumentacija",
    "Developer documentation" : "Dokumentacija za razvijalce",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Ta aplikacija nima določene minimalne NextCloud verzije. V prihodnosti bo to napaka.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Programa ni mogoče namestiti zaradi nerešenih odvisnosti:",
    "Enable" : "Omogoči",
    "The app will be downloaded from the app store" : "Program bo prejet iz zbirke programov",
    "Email" : "Elektronski naslov",
    "Language" : "Jezik",
    "Unlimited" : "Neomejeno",
    "Admins" : "Skrbniki",
    "Everyone" : "Vsi",
    "SSL Root Certificates" : "Korenska potrdila SSL",
    "Common Name" : "Splošno ime",
    "Valid until" : "Veljavno do",
    "Issued By" : "Izdajatelj",
    "Valid until %s" : "Veljavno do %s",
    "Import root certificate" : "Uvozi korensko potrdilo",
    "Administrator documentation" : "Skrbniška dokumentacija",
    "Forum" : "Forum",
    "None" : "Brez",
    "Login" : "Prijava",
    "Plain" : "Besedilno",
    "NT LAN Manager" : "Upravljalnik NT LAN",
    "Email server" : "Poštni strežnik",
    "Open documentation" : "Odprta dokumentacija",
    "Send mode" : "Način pošiljanja",
    "Encryption" : "Šifriranje",
    "From address" : "Naslov pošiljatelja",
    "mail" : "pošta",
    "Authentication method" : "Način overitve",
    "Authentication required" : "Zahtevana je overitev",
    "Server address" : "Naslov strežnika",
    "Port" : "Vrata",
    "Credentials" : "Poverila",
    "SMTP Username" : "Uporabniško ime SMTP",
    "SMTP Password" : "Geslo SMTP",
    "Store credentials" : "Shrani poverila",
    "Test email settings" : "Preizkus nastavitev elektronske pošte",
    "Send email" : "Pošlji elektronsko sporočilo",
    "Server-side encryption" : "Šifriranje na strežniku",
    "Enable server-side encryption" : "Omogoči šifriranje na strežniku",
    "Please read carefully before activating server-side encryption: " : "Pozorno preberite opombe, preden omogočite strežniško šifriranje:",
    "Be aware that encryption always increases the file size." : " Upoštevajte, da šifriranje vedno poveča velikost datoteke.",
    "This is the final warning: Do you really want to enable encryption?" : " To je zadnje opozorilo. Ali resnično želite vključiti šifriranje?",
    "Enable encryption" : "Omogoči šifriranje",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Modul za šifriranje ni naložen. Prosim, omogočite en šifrirni modul v spisku aplikacij.",
    "Select default encryption module:" : "Izbor privzetega modula za šifriranje:",
    "Start migration" : "Začni selitev",
    "Security & setup warnings" : "Varnost in namestitvena opozorila",
    "All checks passed." : "Vsa preverjanja so uspešno zaključena.",
    "Version" : "Različica",
    "Execute one task with each page loaded" : "Izvedi eno nalogo z vsako naloženo stranjo.",
    "Sharing" : "Souporaba",
    "Allow apps to use the Share API" : "Dovoli programom uporabo vmesnika API souporabe",
    "Allow users to share via link" : "Uporabnikom dovoli omogočanje souporabe s povezavami",
    "Allow public uploads" : "Dovoli javno pošiljanje datotek v oblak",
    "Enforce password protection" : "Vsili zaščito z geslom",
    "Set default expiration date" : "Nastavitev privzetega datuma poteka",
    "Expire after " : "Preteče po",
    "days" : "dneh",
    "Enforce expiration date" : "Vsili datum preteka",
    "Allow resharing" : "Dovoli nadaljnjo souporabo",
    "Allow sharing with groups" : "Dovoli souporabo s skupinami",
    "Restrict users to only share with users in their groups" : "Uporabnikom dovoli omogočanje souporabe le znotraj njihove skupine",
    "Exclude groups from sharing" : "Izloči skupine iz souporabe",
    "These groups will still be able to receive shares, but not to initiate them." : "Te skupine lahko sprejemajo mape v souporabo, ne morejo pa souporabe dovoliti",
    "Profile picture" : "Slika profila",
    "Upload new" : "Pošlji novo",
    "Select from Files" : "Izbor iz datotek",
    "Remove image" : "Odstrani sliko",
    "png or jpg, max. 20 MB" : "png ali jpg, največ. 20 MB",
    "Picture provided by original account" : "Slika iz originalnega računa",
    "Cancel" : "Prekliči",
    "Choose as profile picture" : "Izberi kot sliko profila",
    "Full name" : "Polno ime",
    "No display name set" : "Prikazno ime ni nastavljeno",
    "Your email address" : "Osebni elektronski naslov",
    "No email address set" : "Poštni naslov ni nastavljen",
    "Help translate" : "Sodelujte pri prevajanju",
    "Password" : "Geslo",
    "Current password" : "Trenutno geslo",
    "New password" : "Novo geslo",
    "Change password" : "Spremeni geslo",
    "App name" : "Ime aplikacije",
    "Create new app password" : "Ustvari novo geslo aplikacije",
    "Username" : "Uporabniško ime",
    "Done" : "Končano",
    "A problem occurred, please check your log files (Error: %s)" : "Prišlo je do napake. Preverite dnevniške zapise (napaka: %s).",
    "Migration Completed" : "Selitev je končana",
    "Group already exists." : "Skupina že obstaja.",
    "Unable to add group." : "Ni mogoče dodati skupine",
    "Unable to delete group." : "Ni mogoče izbrisati skupine.",
    "A user with that name already exists." : "Uporabnik s tem imenom že obstaja.",
    "Unable to create user." : "Ni mogoče ustvariti uporabnika.",
    "Unable to delete user." : "Ni mogoče izbrisati uporabnika",
    "Your full name has been changed." : "Vaše polno ime je spremenjeno.",
    "Forbidden" : "Dostop je prepovedan",
    "Invalid user" : "Neveljavni podatki uporabnika",
    "Unable to change mail address" : "Ni mogoče spremeniti naslova elektronske pošte.",
    "Email saved" : "Elektronski naslov je shranjen",
    "Add trusted domain" : "Dodaj varno domeno",
    "All" : "Vsi",
    "Update to %s" : "Posodobi na %s",
    "No apps found for your version" : "Za to različico ni na voljo noben vstavek",
    "Error while disabling app" : "Napaka onemogočanja programa",
    "Disable" : "Onemogoči",
    "Error while enabling app" : "Napaka omogočanja programa",
    "Error while disabling broken app" : "Napaka onemogočanja okvarjenega programa",
    "Updated" : "Posodobljeno",
    "Approved" : "Odobreno",
    "Experimental" : "Preizkusno",
    "No apps found for {query}" : "Ni programov, skladnih z nizom \"{query}\".",
    "Unable to delete {objName}" : "Ni mogoče izbrisati {objName}",
    "Error creating group: {message}" : "Napaka ustvarjanja skupine: {message}",
    "A valid group name must be provided" : "Navedeno mora biti veljavno ime skupine",
    "deleted {groupName}" : "izbrisano {groupName}",
    "undo" : "razveljavi",
    "never" : "nikoli",
    "deleted {userName}" : "izbrisano {userName}",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "Sprememba gesla bo povzročila izgubo podatkov, ker obnova podatkov za tega uporabnika ni na voljo.",
    "A valid username must be provided" : "Navedeno mora biti veljavno uporabniško ime",
    "Error creating user: {message}" : "Napaka ustvarjanja uporabnika: {message}",
    "A valid password must be provided" : "Navedeno mora biti veljavno geslo",
    "A valid email must be provided" : "Naveden mora biti veljaven naslov elektronske pošte.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Napako je najverjetneje povzročil predpomnilnik ali pospeševalnik, kot sta Zend OPcache ali eAccelerator.",
    "System locale can not be set to a one which supports UTF-8." : "Sistemskih jezikovnih nastavitev ni mogoče nastaviti na možnost, ki podpira nabor UTF-8.",
    "Tips & tricks" : "Nasveti in triki",
    "How to do backups" : "Kako ustvariti varnostne kopije",
    "Performance tuning" : "Prilagajanje delovanja",
    "Improving the config.php" : "Izboljšave v config.php",
    "Theming" : "Teme",
    "Hardening and security guidance" : "Varnost in varnostni napotki",
    "This app has an update available." : "Za program so na voljo posodobitve.",
    "%s-licensed" : "dovoljenje-%s",
    "Documentation:" : "Dokumentacija:",
    "Admin documentation" : "Skrbniška dokumentacija",
    "Report a bug" : "Pošlji poročilo o hrošču",
    "Show description …" : "Pokaži opis ...",
    "Hide description …" : "Skrij opis ...",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Ta aplikacija nima določene maksimalne NextCloud verzije. V prihodnosti bo to napaka.",
    "Enable only for specific groups" : "Omogoči le za posamezne skupine",
    "Online documentation" : "Spletna dokumentacija",
    "Commercial support" : "Podpora strankam",
    "You are using <strong>%s</strong> of <strong>%s</strong>" : "Uporabljate <strong>%s</strong> od <strong>%s</strong>",
    "You are member of the following groups:" : "Ste član naslednjih skupin:",
    "Show storage location" : "Pokaži mesto shrambe",
    "Show user backend" : "Pokaži ozadnji program",
    "Show email address" : "Pokaži naslov elektronske pošte",
    "Send email to new user" : "Pošlji sporočilo novemu uporabniku",
    "E-Mail" : "Elektronska pošta",
    "Create" : "Ustvari",
    "Admin Recovery Password" : "Obnovitev skrbniškega gesla",
    "Enter the recovery password in order to recover the users files during password change" : "Vnesite geslo, ki omogoča obnovitev uporabniških datotek med spreminjanjem gesla",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Vnesite količinsko omejitev prostora (na primer: \"512 MB\" ali \"12 GB\")",
    "Other" : "Drugo",
    "Quota" : "Količinska omejitev",
    "change full name" : "Spremeni polno ime",
    "set new password" : "nastavi novo geslo",
    "change email address" : "spremeni naslov elektronske pošte",
    "Default" : "Privzeto"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
